package com.shxy.i2.serviceimpl;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.date.DatePattern;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.StrUtil;
import com.shxy.i2.Tool.AsyncMethod;
import com.shxy.i2.Tool.GenerateI2Xml;
import com.shxy.i2.bean.AttrBean;
import com.shxy.i2.bean.SendDataBean;
import com.shxy.i2.constant.CommonStatus;
import com.shxy.i2.constant.Constant;
import com.shxy.i2.dao.*;
import com.shxy.i2.entity.*;
import com.shxy.i2.service.XydlI2Service;
import lombok.extern.slf4j.Slf4j;
import org.apache.cxf.endpoint.Client;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;

@Service
@Slf4j
public class XydlI2ServiceImpl implements XydlI2Service {


    @Autowired
    private Data_SF6_QtylDao data_sf6_qtylDao;

    @Autowired
    private Data_Byq_JbfdDao data_byq_jbfdDao;

    @Autowired
    private Data_CnjDao data_cnjDao;

    @Autowired
    private Data_DcywDao data_dcywDao;

    @Autowired
    private Data_Dlq_JbfdDao data_dlq_jbfdDao;

    @Autowired
    private Data_Dr_JyjcDao data_dr_jyjcDao;

    @Autowired
    private Data_FhdlbxDao data_fhdlbxDao;

    @Autowired
    private Data_FhzxqDao data_fhzxqDao;

    @Autowired
    private Data_Jsyhw_JyjcDao data_jsyhw_jyjcDao;

    @Autowired
    private Data_SF6_QtsfDao data_sf6_qtsfDao;

    @Autowired
    private Data_TxDao data_txDao;

    @Autowired
    private Data_WsDao data_wsDao;

    @Autowired
    private Data_YspDao data_yspDao;

    @Autowired
    private Data_MicroclimateDao data_microclimateDao;

    @Autowired
    AsyncMethod asyncMethod;


    @Override
    public void upload_byq_jbfd(Client client, HashMap<Integer, Niec_Sensors> equipMap) {
        List<Data_Byq_Jbfd> list = data_byq_jbfdDao.selectUpload(CommonStatus.UNUPLOAD.value());
        if (CollectionUtil.isNotEmpty(list)) {
            log.info("查询byq_jbfd的数据量：" + list.size());
            ArrayList<String> cacdatalist = new ArrayList<>();
            ArrayList<BigInteger> idlist = new ArrayList<>();
            ArrayList<SendDataBean> list2 = new ArrayList<>();
            ArrayList<Integer> eqmidlist = new ArrayList<>();
            BigInteger maxid = BigInteger.valueOf(0);
            for (int index = 0; index < list.size(); index++) {
                Data_Byq_Jbfd item = list.get(index);
                Niec_Sensors sensors = equipMap.get(item.getEqmid());
                String sensorid = sensors.getSensorCode();
                String equipmentid = sensors.getEquipmentId();
                String phase = sensors.getPhase();

                if (StrUtil.isNotEmpty(sensorid) && StrUtil.isNotEmpty(equipmentid)) {
                    ArrayList<AttrBean> attrlist = new ArrayList<>();
                    try {
                        String timestamp = "";
                        Date acquisitiontime = item.getAcquisitiontime();
                        if (acquisitiontime != null) {
                            timestamp = DateUtil.format(acquisitiontime, DatePattern.NORM_DATETIME_PATTERN);
                        }
                        if (phase != null) {
                            AttrBean<String> attr = new AttrBean<>();
                            attr.setKey("Phase");
                            attr.setValue(phase);
                            attrlist.add(attr);
                        }
                        Float dischargecapacity = item.getDischargecapacity();
                        if (dischargecapacity != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("DischargeCapacity");
                            attr.setValue(dischargecapacity);
                            attrlist.add(attr);
                        }
                        Float dischargeposition = item.getDischargeposition();
                        if (dischargeposition != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("DischargePosition");
                            attr.setValue(dischargeposition);
                            attrlist.add(attr);
                        }
                        Float pulsecount = item.getPulsecount();
                        if (pulsecount != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("PulseCount");
                            attr.setValue(pulsecount);
                            attrlist.add(attr);
                        }
                        byte[] dischargewaveform = item.getDischargewaveform();
                        if (dischargewaveform != null) {
                            AttrBean<byte[]> attr = new AttrBean<>();
                            attr.setKey("DischargeWaveform");
                            attr.setValue(dischargewaveform);
                            attrlist.add(attr);
                        }
                        String cacdata = GenerateI2Xml.generateCacXml(Constant.BYQ_JBFD, sensorid, equipmentid, timestamp, attrlist);
                        cacdatalist.add(cacdata);
                        BigInteger id = item.getId();
                        idlist.add(id);
                        SendDataBean sendDataBean = new SendDataBean();
                        sendDataBean.setEqmid(item.getEqmid());
                        sendDataBean.setMaxid(id);
                        list2.add(sendDataBean);
                        eqmidlist.add(item.getEqmid());
                        if (id != null) {
                            int i = id.compareTo(maxid);
                            if (i == 1) {
                                maxid = id;
                            }
                        }
                        if ((index != 0 && index % 79 == 0) || index == (list.size() - 1)) {
                            ArrayList<BigInteger> list1 = new ArrayList<>();
                            String xml = GenerateI2Xml.generateEndCacXml(cacdatalist);
                            list1.addAll(idlist);
//                            asyncMethod.sendJBFDData(client, list2, xml, Constant.BYQ_JBFD);
                            asyncMethod.sendJBFDData2(client,maxid, eqmidlist, xml, Constant.BYQ_JBFD);
                            idlist = new ArrayList<>();
                            maxid = BigInteger.valueOf(0);
                            eqmidlist = new ArrayList<>();
                            cacdatalist = new ArrayList<>();
                        }
                    } catch (Exception e) {
                        log.error("抛出了异常：{}" + e.getMessage());
                    }
                }
            }
        } else {
            log.info("没有查询byq_jbfd的数据量");
        }
    }

    @Override
    public void upload_cnj(Client client, HashMap<Integer, Niec_Sensors> equipMap) {
        List<Data_Cnj> list = data_cnjDao.selectUpload(CommonStatus.UNUPLOAD.value());
        if (CollectionUtil.isNotEmpty(list)) {
            log.info("查询byq_jbfd的数据量：" + list.size());
            ArrayList<String> cacdatalist = new ArrayList<>();
            ArrayList<BigInteger> idlist = new ArrayList<>();
            for (int index = 0; index < list.size(); index++) {
                Data_Cnj item = list.get(index);
                Niec_Sensors sensors = equipMap.get(item.getEqmid());
                String sensorid = sensors.getSensorCode();
                String equipmentid = sensors.getEquipmentId();
                String phase = sensors.getPhase();
                if (StrUtil.isNotEmpty(sensorid) && StrUtil.isNotEmpty(equipmentid)) {
                    ArrayList<AttrBean> attrlist = new ArrayList<>();
                    try {
                        String timestamp = "";
                        Date acquisitiontime = item.getAcquisitiontime();
                        if (acquisitiontime != null) {
                            timestamp = DateUtil.format(acquisitiontime, DatePattern.NORM_DATETIME_PATTERN);
                        }
                        if (phase != null) {
                            AttrBean<String> attr = new AttrBean<>();
                            attr.setKey("Phase");
                            attr.setValue(phase);
                            attrlist.add(attr);
                        }
                        Float chargetime = item.getChargetime();
                        if (chargetime != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("ChargeTime");
                            attr.setValue(chargetime);
                            attrlist.add(attr);
                        }
                        String cacdata = GenerateI2Xml.generateCacXml(Constant.CNJ, sensorid, equipmentid, timestamp, attrlist);
                        cacdatalist.add(cacdata);
                        idlist.add(item.getId());
                        if ((index != 0 && index % 79 == 0) || index == (list.size() - 1)) {
                            ArrayList<BigInteger> list1 = new ArrayList<>();
                            String xml = GenerateI2Xml.generateEndCacXml(cacdatalist);
                            list1.addAll(idlist);
                            asyncMethod.sendData(client, list1, xml, Constant.CNJ);
                            idlist = new ArrayList<>();
                            cacdatalist = new ArrayList<>();
                        }
                    } catch (Exception e) {
                        log.error("抛出了异常：{}" + e.getMessage());
                    }
                }
            }
        } else {
            log.info("没有查询cnj的数据量");
        }
    }

    @Override
    public void upload_dcyw(Client client, HashMap<Integer, Niec_Sensors> equipMap) {
        List<Data_Dcyw> list = data_dcywDao.selectUpload(CommonStatus.UNUPLOAD.value());
        if (CollectionUtil.isNotEmpty(list)) {
            log.info("查询dcyw的数据量：" + list.size());
            ArrayList<String> cacdatalist = new ArrayList<>();
            ArrayList<BigInteger> idlist = new ArrayList<>();
            for (int index = 0; index < list.size(); index++) {
                Data_Dcyw item = list.get(index);
                Niec_Sensors sensors = equipMap.get(item.getEqmid());
                String sensorid = sensors.getSensorCode();
                String equipmentid = sensors.getEquipmentId();
                String phase = sensors.getPhase();

                if (StrUtil.isNotEmpty(sensorid) && StrUtil.isNotEmpty(equipmentid)) {

                    ArrayList<AttrBean> attrlist = new ArrayList<>();
                    try {
                        String timestamp = "";
                        Date acquisitiontime = item.getAcquisitiontime();
                        if (acquisitiontime != null) {
                            timestamp = DateUtil.format(acquisitiontime, DatePattern.NORM_DATETIME_PATTERN);
                        }
                        if (phase != null) {
                            AttrBean<String> attr = new AttrBean<>();
                            attr.setKey("Phase");
                            attr.setValue(phase);
                            attrlist.add(attr);
                        }
                        Float oiltemperature = item.getOiltemperature();
                        if (oiltemperature != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("OilTemperature");
                            attr.setValue(oiltemperature);
                            attrlist.add(attr);
                        }
                        String cacdata = GenerateI2Xml.generateCacXml(Constant.DCYW, sensorid, equipmentid, timestamp, attrlist);
                        cacdatalist.add(cacdata);
                        idlist.add(item.getId());
                        if ((index != 0 && index % 79 == 0) || index == (list.size() - 1)) {
                            ArrayList<BigInteger> list1 = new ArrayList<>();
                            String xml = GenerateI2Xml.generateEndCacXml(cacdatalist);
                            list1.addAll(idlist);
                            asyncMethod.sendData(client, list1, xml, Constant.DCYW);
                            idlist = new ArrayList<>();
                            cacdatalist = new ArrayList<>();
                        }
                    } catch (Exception e) {
                        log.error("抛出了异常：{}" + e.getMessage());
                    }
                }
            }
        } else {
            log.info("没有查询dcyw的数据量");
        }
    }

    @Override
    public void upload_dlq_jbfd(Client client, HashMap<Integer, Niec_Sensors> equipMap) {
        List<Data_Dlq_Jbfd> list = data_dlq_jbfdDao.selectUpload(CommonStatus.UNUPLOAD.value());
        if (CollectionUtil.isNotEmpty(list)) {
            log.info("查询dlq_jbfd的数据量：" + list.size());
            ArrayList<String> cacdatalist = new ArrayList<>();
            ArrayList<BigInteger> idlist = new ArrayList<>();
            ArrayList<SendDataBean> list2 = new ArrayList<>();

            ArrayList<Integer> eqmidlist = new ArrayList<>();
            BigInteger maxid = BigInteger.valueOf(0);
            for (int index = 0; index < list.size(); index++) {
                Data_Dlq_Jbfd item = list.get(index);
                Niec_Sensors sensors = equipMap.get(item.getEqmid());
                String sensorid = sensors.getSensorCode();
                String equipmentid = sensors.getEquipmentId();
                String phase = sensors.getPhase();
                if (StrUtil.isNotEmpty(sensorid) && StrUtil.isNotEmpty(equipmentid)) {
                    ArrayList<AttrBean> attrlist = new ArrayList<>();
                    try {
                        String timestamp = "";
                        Date acquisitiontime = item.getAcquisitiontime();
                        if (acquisitiontime != null) {
                            timestamp = DateUtil.format(acquisitiontime, DatePattern.NORM_DATETIME_PATTERN);
                        }
                        if (phase != null) {
                            AttrBean<String> attr = new AttrBean<>();
                            attr.setKey("Phase");
                            attr.setValue(phase);
                            attrlist.add(attr);
                        }
                        Float dischargecapacity = item.getDischargecapacity();
                        if (dischargecapacity != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("DischargeCapacity");
                            attr.setValue(dischargecapacity);
                            attrlist.add(attr);
                        }
                        Float dischargeposition = item.getDischargeposition();
                        if (dischargeposition != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("DischargePosition");
                            attr.setValue(dischargeposition);
                            attrlist.add(attr);
                        }
                        Float pulsecount = item.getPulsecount();
                        if (pulsecount != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("PulseCount");
                            attr.setValue(pulsecount);
                            attrlist.add(attr);
                        }
                        byte[] dischargewaveform = item.getDischargewaveform();
                        if (dischargewaveform != null) {
                            AttrBean<byte[]> attr = new AttrBean<>();
                            attr.setKey("DischargeWaveform");
                            attr.setValue(dischargewaveform);
                            attrlist.add(attr);
                        }
                        String cacdata = GenerateI2Xml.generateCacXml(Constant.DLQJBFD, sensorid, equipmentid, timestamp, attrlist);
                        cacdatalist.add(cacdata);
                        BigInteger id = item.getId();
                        idlist.add(id);
                        SendDataBean sendDataBean = new SendDataBean();
                        sendDataBean.setEqmid(item.getEqmid());
                        sendDataBean.setMaxid(id);
                        list2.add(sendDataBean);
                        eqmidlist.add(item.getEqmid());
                        if (id != null) {
                            int i = id.compareTo(maxid);
                            if (i == 1) {
                                maxid = id;
                            }
                        }
                        if ((index != 0 && index % 79 == 0) || index == (list.size() - 1)) {
                            ArrayList<BigInteger> list1 = new ArrayList<>();
                            String xml = GenerateI2Xml.generateEndCacXml(cacdatalist);
                            list1.addAll(idlist);
//                            asyncMethod.sendJBFDData(client, list2, xml, Constant.DLQJBFD);
                            asyncMethod.sendJBFDData2(client,maxid, eqmidlist, xml, Constant.DLQJBFD);
                            maxid = BigInteger.valueOf(0);
                            eqmidlist = new ArrayList<>();
                            idlist = new ArrayList<>();
                            cacdatalist = new ArrayList<>();
                        }
                    } catch (Exception e) {
                        log.error("抛出了异常：{}" + e.getMessage());
                    }
                }
            }
        } else {
            log.info("没有查询到dlq的数据");
        }
    }

    @Override
    public void upload_dr_jyjc(Client client, HashMap<Integer, Niec_Sensors> equipMap) {
        List<Data_Dr_Jyjc> list = data_dr_jyjcDao.selectUpload(CommonStatus.UNUPLOAD.value());
        if (CollectionUtil.isNotEmpty(list)) {
            log.info("查询dr_jyjc的数据量：" + list.size());
            ArrayList<String> cacdatalist = new ArrayList<>();
            ArrayList<BigInteger> idlist = new ArrayList<>();
            for (int index = 0; index < list.size(); index++) {
                Data_Dr_Jyjc item = list.get(index);
                Niec_Sensors sensors = equipMap.get(item.getEqmid());
                String sensorid = sensors.getSensorCode();
                String equipmentid = sensors.getEquipmentId();
                String phase = sensors.getPhase();
                if (StrUtil.isNotEmpty(sensorid) && StrUtil.isNotEmpty(equipmentid)) {
                    ArrayList<AttrBean> attrlist = new ArrayList<>();
                    try {
                        String timestamp = "";
                        Date acquisitiontime = item.getAcquisitiontime();
                        if (acquisitiontime != null) {
                            timestamp = DateUtil.format(acquisitiontime, DatePattern.NORM_DATETIME_PATTERN);
                        }
                        if (phase != null) {
                            AttrBean<String> attr = new AttrBean<>();
                            attr.setKey("Phase");
                            attr.setValue(phase);
                            attrlist.add(attr);
                        }
                        Float capacitance = item.getCapacitance();
                        if (capacitance != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("Capacitance");
                            attr.setValue(capacitance);
                            attrlist.add(attr);
                        }
                        Float lossfactor = item.getLossfactor();
                        if (lossfactor != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("LossFactor");
                            attr.setValue(lossfactor);
                            attrlist.add(attr);
                        }
                        Float unbalancecurrent = item.getUnbalancecurrent();
                        if (unbalancecurrent != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("UnbalanceCurrent");
                            attr.setValue(unbalancecurrent);
                            attrlist.add(attr);
                        }
                        Float unbalancevoltage = item.getUnbalancevoltage();
                        if (unbalancevoltage != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("UnbalanceVoltage");
                            attr.setValue(unbalancevoltage);
                            attrlist.add(attr);
                        }
                        Float totalcurrent = item.getTotalcurrent();
                        if (totalcurrent != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("TotalCurrent");
                            attr.setValue(totalcurrent);
                            attrlist.add(attr);
                        }
                        Float systemvoltage = item.getSystemvoltage();
                        if (systemvoltage != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("SystemVoltage");
                            attr.setValue(systemvoltage);
                            attrlist.add(attr);
                        }
                        String cacdata = GenerateI2Xml.generateCacXml(Constant.DRJYJC, sensorid, equipmentid, timestamp, attrlist);
                        cacdatalist.add(cacdata);
                        idlist.add(item.getId());
                        if ((index != 0 && index % 79 == 0) || index == (list.size() - 1)) {
                            ArrayList<BigInteger> list1 = new ArrayList<>();
                            String xml = GenerateI2Xml.generateEndCacXml(cacdatalist);
                            list1.addAll(idlist);
                            asyncMethod.sendData(client, list1, xml, Constant.DRJYJC);
                            idlist = new ArrayList<>();
                            cacdatalist = new ArrayList<>();
                        }
                    } catch (Exception e) {
                        log.error("抛出了异常：{}" + e.getMessage());
                    }
                }
            }
        } else {
            log.info("没有查询dr_jyjc的数据量");
        }
    }

    @Override
    public void upload_fhdlbx(Client client, HashMap<Integer, Niec_Sensors> equipMap) {
        List<Data_Fhdlbx> list = data_fhdlbxDao.selectUpload(CommonStatus.UNUPLOAD.value());
        if (CollectionUtil.isNotEmpty(list)) {
            log.info("查询fhdlbx的数据量：" + list.size());
            ArrayList<String> cacdatalist = new ArrayList<>();
            ArrayList<BigInteger> idlist = new ArrayList<>();
            for (int index = 0; index < list.size(); index++) {
                Data_Fhdlbx item = list.get(index);
                Niec_Sensors sensors = equipMap.get(item.getEqmid());
                String sensorid = sensors.getSensorCode();
                String equipmentid = sensors.getEquipmentId();
                String phase = sensors.getPhase();
                if (StrUtil.isNotEmpty(sensorid) && StrUtil.isNotEmpty(equipmentid)) {
                    ArrayList<AttrBean> attrlist = new ArrayList<>();
                    try {
                        String timestamp = "";
                        Date acquisitiontime = item.getAcquisitiontime();
                        if (acquisitiontime != null) {
                            timestamp = DateUtil.format(acquisitiontime, DatePattern.NORM_DATETIME_PATTERN);
                        }
                        if (phase != null) {
                            AttrBean<String> attr = new AttrBean<>();
                            attr.setKey("Phase");
                            attr.setValue(phase);
                            attrlist.add(attr);
                        }
                        Integer action = item.getAction();
                        if (action != null) {
                            AttrBean<Integer> attr = new AttrBean<>();
                            attr.setKey("Action");
                            attr.setValue(action);
                            attrlist.add(attr);
                        }
                        byte[] loadwaveform = item.getLoadwaveform();
                        if (loadwaveform != null) {
                            AttrBean<byte[]> attr = new AttrBean<>();
                            attr.setKey("LoadWaveform");
                            attr.setValue(loadwaveform);
                            attrlist.add(attr);
                        }
                        String cacdata = GenerateI2Xml.generateCacXml(Constant.FHDLBX, sensorid, equipmentid, timestamp, attrlist);
                        cacdatalist.add(cacdata);
                        idlist.add(item.getId());
                        if ((index != 0 && index % 79 == 0) || index == (list.size() - 1)) {
                            ArrayList<BigInteger> list1 = new ArrayList<>();
                            String xml = GenerateI2Xml.generateEndCacXml(cacdatalist);
                            list1.addAll(idlist);
                            asyncMethod.sendData(client, list1, xml, Constant.FHDLBX);
                            idlist = new ArrayList<>();
                            cacdatalist = new ArrayList<>();
                        }
                    } catch (Exception e) {
                        log.error("抛出了异常：{}" + e.getMessage());
                    }
                }
            }
        } else {
            log.info("没有查询fhdlbx的数据量");
        }
    }

    @Override
    public void upload_fhzxq(Client client, HashMap<Integer, Niec_Sensors> equipMap) {
        List<Data_Fhzxq> list = data_fhzxqDao.selectUpload(CommonStatus.UNUPLOAD.value());
        if (CollectionUtil.isNotEmpty(list)) {
            log.info("查询fhzxq的数据量：" + list.size());
            ArrayList<BigInteger> idlist = new ArrayList<>();
            ArrayList<String> cacdatalist = new ArrayList<>();
            for (int index = 0; index < list.size(); index++) {
                Data_Fhzxq item = list.get(index);
                Niec_Sensors sensors = equipMap.get(item.getEqmid());
                String sensorid = sensors.getSensorCode();
                String equipmentid = sensors.getEquipmentId();
                String phase = sensors.getPhase();
                if (StrUtil.isNotEmpty(sensorid) && StrUtil.isNotEmpty(equipmentid)) {
                    ArrayList<AttrBean> attrlist = new ArrayList<>();
                    try {
                        String timestamp = "";
                        Date acquisitiontime = item.getAcquisitiontime();
                        if (acquisitiontime != null) {
                            timestamp = DateUtil.format(acquisitiontime, DatePattern.NORM_DATETIME_PATTERN);
                        }
                        if (phase != null) {
                            AttrBean<String> attr = new AttrBean<>();
                            attr.setKey("Phase");
                            attr.setValue(phase);
                            attrlist.add(attr);
                        }
                        Integer action = item.getAction();
                        if (action != null) {
                            AttrBean<Integer> attr = new AttrBean<>();
                            attr.setKey("Action");
                            attr.setValue(action);
                            attrlist.add(attr);
                        }
                        byte[] coilwaveform = item.getCoilwaveform();
                        if (coilwaveform != null) {
                            AttrBean<byte[]> attr = new AttrBean<>();
                            attr.setKey("CoilWaveform");
                            attr.setValue(coilwaveform);
                            attrlist.add(attr);
                        }
                        String cacdata = GenerateI2Xml.generateCacXml(Constant.FHZXQ, sensorid, equipmentid, timestamp, attrlist);
                        cacdatalist.add(cacdata);
                        idlist.add(item.getId());
                        if ((index != 0 && index % 79 == 0) || index == (list.size() - 1)) {
                            ArrayList<BigInteger> list1 = new ArrayList<>();
                            String xml = GenerateI2Xml.generateEndCacXml(cacdatalist);
                            list1.addAll(idlist);
                            asyncMethod.sendData(client, list1, xml, Constant.FHZXQ);
                            idlist = new ArrayList<>();
                            cacdatalist = new ArrayList<>();
                        }
                    } catch (Exception e) {
                        log.error("抛出了异常：{}" + e.getMessage());
                    }
                }
            }
        } else {
            log.info("没有查询fhzxq的数据量");
        }
    }

    @Override
    public void upload_jsyhw_jyjc(Client client, HashMap<Integer, Niec_Sensors> equipMap) {
        List<Data_Jsyhw_Jyjc> list = data_jsyhw_jyjcDao.selectUpload(CommonStatus.UNUPLOAD.value());
        if (CollectionUtil.isNotEmpty(list)) {
            log.info("查询jsyhw_jyjc的数据量：" + list.size());
            ArrayList<String> cacdatalist = new ArrayList<>();
            ArrayList<BigInteger> idlist = new ArrayList<>();
            for (int index = 0; index < list.size(); index++) {
                Data_Jsyhw_Jyjc item = list.get(index);
                Niec_Sensors sensors = equipMap.get(item.getEqmid());
                String sensorid = sensors.getSensorCode();
                String equipmentid = sensors.getEquipmentId();
                String phase = sensors.getPhase();
                if (StrUtil.isNotEmpty(sensorid) && StrUtil.isNotEmpty(equipmentid)) {
                    ArrayList<AttrBean> attrlist = new ArrayList<>();
                    try {
                        String timestamp = "";
                        Date acquisitiontime = item.getAcquisitiontime();
                        if (acquisitiontime != null) {
                            timestamp = DateUtil.format(acquisitiontime, DatePattern.NORM_DATETIME_PATTERN);
                        }
                        if (phase != null) {
                            AttrBean<String> attr = new AttrBean<>();
                            attr.setKey("Phase");
                            attr.setValue(phase);
                            attrlist.add(attr);
                        }
                        Float systemvoltage = item.getSystemvoltage();
                        if (systemvoltage != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("SystemVoltage");
                            attr.setValue(systemvoltage);
                            attrlist.add(attr);
                        }
                        Float totalcurrent = item.getTotalcurrent();
                        if (totalcurrent != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("TotalCurrent");
                            attr.setValue(totalcurrent);
                            attrlist.add(attr);
                        }
                        Float resistivecurrent = item.getResistivecurrent();
                        if (resistivecurrent != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("ResistiveCurrent");
                            attr.setValue(resistivecurrent);
                            attrlist.add(attr);
                        }
                        Float actioncount = item.getActioncount();
                        if (actioncount != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("ActionCount");
                            attr.setValue(actioncount);
                            attrlist.add(attr);
                        }
                        Date lastactiontime = item.getLastactiontime();
                        if (lastactiontime != null) {
                            AttrBean<String> attr = new AttrBean<>();
                            attr.setKey("LastActionTime");
                            attr.setValue(DateUtil.format(lastactiontime, DatePattern.NORM_DATETIME_PATTERN));
                            attrlist.add(attr);
                        }
                        String cacdata = GenerateI2Xml.generateCacXml(Constant.JSYHW, sensorid, equipmentid, timestamp, attrlist);
                        cacdatalist.add(cacdata);
                        idlist.add(item.getId());
                        if ((index != 0 && index % 79 == 0) || index == (list.size() - 1)) {
                            ArrayList<BigInteger> list1 = new ArrayList<>();
                            String xml = GenerateI2Xml.generateEndCacXml(cacdatalist);
                            list1.addAll(idlist);
                            asyncMethod.sendData(client, list1, xml, Constant.JSYHW);
                            idlist = new ArrayList<>();
                            cacdatalist = new ArrayList<>();
                        }
                    } catch (Exception e) {
                        log.error("抛出了异常：{}" + e.getMessage());
                    }
                }
            }
        } else {
            log.info("没有查询jsyhw_jyjc的数据量");
        }
    }

    @Override
    public void upload_sf6_qtsf(Client client, HashMap<Integer, Niec_Sensors> equipMap) {
        List<Data_SF6_Qtsf> list = data_sf6_qtsfDao.selectUpload(CommonStatus.UNUPLOAD.value());
        if (CollectionUtil.isNotEmpty(list)) {
            log.info("查询sf6_qtsf的数据量：" + list.size());
            ArrayList<String> cacdatalist = new ArrayList<>();
            ArrayList<BigInteger> idlist = new ArrayList<>();
            for (int index = 0; index < list.size(); index++) {
                Data_SF6_Qtsf item = list.get(index);
                Niec_Sensors sensors = equipMap.get(item.getEqmid());
                String sensorid = sensors.getSensorCode();
                String equipmentid = sensors.getEquipmentId();
                String phase = sensors.getPhase();
                if (StrUtil.isNotEmpty(sensorid) && StrUtil.isNotEmpty(equipmentid)) {
                    ArrayList<AttrBean> attrlist = new ArrayList<>();
                    try {
                        String timestamp = "";
                        Date acquisitiontime = item.getAcquisitiontime();
                        if (acquisitiontime != null) {
                            timestamp = DateUtil.format(acquisitiontime, DatePattern.NORM_DATETIME_PATTERN);
                        }
                        if (phase != null) {
                            AttrBean<String> attr = new AttrBean<>();
                            attr.setKey("Phase");
                            attr.setValue(phase);
                            attrlist.add(attr);
                        }
                        Float temperature = item.getTemperature();
                        if (temperature != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("Temperature");
                            attr.setValue(temperature);
                            attrlist.add(attr);
                        }
                        Float moisture = item.getMoisture();
                        if (moisture != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("Moisture");
                            attr.setValue(moisture);
                            attrlist.add(attr);
                        }
                        String cacdata = GenerateI2Xml.generateCacXml(Constant.SF6_QTSF, sensorid, equipmentid, timestamp, attrlist);
                        cacdatalist.add(cacdata);
                        idlist.add(item.getId());
                        if ((index != 0 && index % 79 == 0) || index == (list.size() - 1)) {
                            ArrayList<BigInteger> list1 = new ArrayList<>();
                            String xml = GenerateI2Xml.generateEndCacXml(cacdatalist);
                            list1.addAll(idlist);
                            asyncMethod.sendData(client, list1, xml, Constant.SF6_QTSF);
                            idlist = new ArrayList<>();
                            cacdatalist = new ArrayList<>();
                        }
                    } catch (Exception e) {
                        log.error("抛出了异常：{}" + e.getMessage());
                    }
                }
            }
        } else {
            log.info("没有查询sf6_qtsf的数据量");
        }
    }

    @Override
    public void upload_sf6_qtyl(Client client, HashMap<Integer, Niec_Sensors> equipMap) {
        List<Data_SF6_Qtyl> list = data_sf6_qtylDao.selectUpload(CommonStatus.UNUPLOAD.value());
        if (CollectionUtil.isNotEmpty(list)) {
            log.info("查询sf6_qtyl的数据量：" + list.size());
            ArrayList<String> cacdatalist = new ArrayList<>();
            ArrayList<BigInteger> idlist = new ArrayList<>();
            for (int index = 0; index < list.size(); index++) {
                Data_SF6_Qtyl item = list.get(index);
                Niec_Sensors sensors = equipMap.get(item.getEqmid());
                String sensorid = sensors.getSensorCode();
                String equipmentid = sensors.getEquipmentId();
                String phase = sensors.getPhase();
                if (StrUtil.isNotEmpty(sensorid) && StrUtil.isNotEmpty(equipmentid)) {
                    ArrayList<AttrBean> attrlist = new ArrayList<>();
                    try {
                        String timestamp = "";
                        Date acquisitiontime = item.getAcquisitiontime();
                        if (acquisitiontime != null) {
                            timestamp = DateUtil.format(acquisitiontime, DatePattern.NORM_DATETIME_PATTERN);
                        }
                        if (phase != null) {
                            AttrBean<String> attr = new AttrBean<>();
                            attr.setKey("Phase");
                            attr.setValue(phase);
                            attrlist.add(attr);
                        }
                        Float temperature = item.getTemperature();
                        if (temperature != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("Temperature");
                            attr.setValue(temperature);
                            attrlist.add(attr);
                        }
                        Float absolutepressure = item.getAbsolutepressure();
                        if (absolutepressure != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("AbsolutePressure");
                            attr.setValue(absolutepressure);
                            attrlist.add(attr);
                        }
                        Float density = item.getDensity();
                        if (density != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("Density");
                            attr.setValue(density);
                            attrlist.add(attr);
                        }
                        Float pressure20c = item.getPressure20c();
                        if (pressure20c != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("Pressure20C");
                            attr.setValue(pressure20c);
                            attrlist.add(attr);
                        }
                        String cacdata = GenerateI2Xml.generateCacXml(Constant.SF6_QTYL, sensorid, equipmentid, timestamp, attrlist);
                        cacdatalist.add(cacdata);
                        idlist.add(item.getId());
                        if ((index != 0 && index % 79 == 0) || index == (list.size() - 1)) {
                            ArrayList<BigInteger> list1 = new ArrayList<>();
                            String xml = GenerateI2Xml.generateEndCacXml(cacdatalist);
                            list1.addAll(idlist);
                            asyncMethod.sendData(client, list1, xml, Constant.SF6_QTYL);
                            idlist = new ArrayList<>();
                            cacdatalist = new ArrayList<>();
                        }
                    } catch (Exception e) {
                        log.error("抛出了异常：{}" + e.getMessage());
                    }
                }
            }
        } else {
            log.info("没有查询到sf6_qtyl的数据");
        }
    }

    @Override
    public void upload_tx(Client client, HashMap<Integer, Niec_Sensors> equipMap) {
        List<Data_Tx> list = data_txDao.selectUpload(CommonStatus.UNUPLOAD.value());
        if (CollectionUtil.isNotEmpty(list)) {
            log.info("查询tx的数据量：" + list.size());
            ArrayList<String> cacdatalist = new ArrayList<>();
            ArrayList<BigInteger> idlist = new ArrayList<>();
            for (int index = 0; index < list.size(); index++) {
                Data_Tx item = list.get(index);
                Niec_Sensors sensors = equipMap.get(item.getEqmid());
                String sensorid = sensors.getSensorCode();
                String equipmentid = sensors.getEquipmentId();
                String phase = sensors.getPhase();
                if (StrUtil.isNotEmpty(sensorid) && StrUtil.isNotEmpty(equipmentid)) {
                    ArrayList<AttrBean> attrlist = new ArrayList<>();
                    try {
                        String timestamp = "";
                        Date acquisitiontime = item.getAcquisitiontime();
                        if (acquisitiontime != null) {
                            timestamp = DateUtil.format(acquisitiontime, DatePattern.NORM_DATETIME_PATTERN);
                        }
                        if (phase != null) {
                            AttrBean<String> attr = new AttrBean<>();
                            attr.setKey("Phase");
                            attr.setValue(phase);
                            attrlist.add(attr);
                        }
                        Float totalcorecurrent = item.getTotalcorecurrent();
                        if (totalcorecurrent != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("TotalCoreCurrent");
                            attr.setValue(totalcorecurrent);
                            attrlist.add(attr);
                        }
                        String cacdata = GenerateI2Xml.generateCacXml(Constant.TX, sensorid, equipmentid, timestamp, attrlist);
                        cacdatalist.add(cacdata);
                        idlist.add(item.getId());
                        if ((index != 0 && index % 79 == 0) || index == (list.size() - 1)) {
                            ArrayList<BigInteger> list1 = new ArrayList<>();
                            String xml = GenerateI2Xml.generateEndCacXml(cacdatalist);
                            list1.addAll(idlist);
                            asyncMethod.sendData(client, list1, xml, Constant.TX);
                            idlist = new ArrayList<>();
                            cacdatalist = new ArrayList<>();
                        }
                    } catch (Exception e) {
                        log.error("抛出了异常：{}" + e.getMessage());
                    }
                }
            }
        } else {
            log.info("没有查询到tx的数据");
        }
    }

    @Override
    public void upload_ws(Client client, HashMap<Integer, Niec_Sensors> equipMap) {
        List<Data_Ws> list = data_wsDao.selectUpload(CommonStatus.UNUPLOAD.value());
        if (CollectionUtil.isNotEmpty(list)) {
            log.info("查询ws的数据量：" + list.size());
            ArrayList<String> cacdatalist = new ArrayList<>();
            ArrayList<BigInteger> idlist = new ArrayList<>();
            for (int index = 0; index < list.size(); index++) {
                Data_Ws item = list.get(index);
                Niec_Sensors sensors = equipMap.get(item.getEqmid());
                String sensorid = sensors.getSensorCode();
                String equipmentid = sensors.getEquipmentId();
                String phase = sensors.getPhase();
                if (StrUtil.isNotEmpty(sensorid) && StrUtil.isNotEmpty(equipmentid)) {
                    ArrayList<AttrBean> attrlist = new ArrayList<>();
                    try {
                        String timestamp = "";
                        Date acquisitiontime = item.getAcquisitiontime();
                        if (acquisitiontime != null) {
                            timestamp = DateUtil.format(acquisitiontime, DatePattern.NORM_DATETIME_PATTERN);
                        }
                        if (phase != null) {
                            AttrBean<String> attr = new AttrBean<>();
                            attr.setKey("Phase");
                            attr.setValue(phase);
                            attrlist.add(attr);
                        }
                        Float moisture = item.getMoisture();
                        if (moisture != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("Moisture");
                            attr.setValue(moisture);
                            attrlist.add(attr);
                        }
                        String cacdata = GenerateI2Xml.generateCacXml(Constant.WS, sensorid, equipmentid, timestamp, attrlist);
                        cacdatalist.add(cacdata);
                        idlist.add(item.getId());
                        if ((index != 0 && index % 79 == 0) || index == (list.size() - 1)) {
                            ArrayList<BigInteger> list1 = new ArrayList<>();
                            String xml = GenerateI2Xml.generateEndCacXml(cacdatalist);
                            list1.addAll(idlist);
                            asyncMethod.sendData(client, list1, xml, Constant.WS);
                            idlist = new ArrayList<>();
                            cacdatalist = new ArrayList<>();
                        }
                    } catch (Exception e) {
                        log.error("抛出了异常：{}" + e.getMessage());
                    }
                }
            }
        } else {
            log.info("没有查询到ws的数据");
        }
    }

    @Override
    public void upload_ysp(Client client, HashMap<Integer, Niec_Sensors> equipMap) {
        List<Data_Ysp> list = data_yspDao.selectUpload(CommonStatus.UNUPLOAD.value());
        if (CollectionUtil.isNotEmpty(list)) {
            log.info("查询ysp的数据量：" + list.size());
            ArrayList<String> cacdatalist = new ArrayList<>();
            ArrayList<BigInteger> idlist = new ArrayList<>();
            ArrayList<SendDataBean> list2 = new ArrayList<>();

            ArrayList<Integer> eqmidlist = new ArrayList<>();
            BigInteger maxid = BigInteger.valueOf(0);
            for (int index = 0; index < list.size(); index++) {
                Data_Ysp item = list.get(index);
                Niec_Sensors sensors = equipMap.get(item.getEqmid());
                String sensorid = sensors.getSensorCode();
                String equipmentid = sensors.getEquipmentId();
                String phase = sensors.getPhase();
                if (StrUtil.isNotEmpty(sensorid) && StrUtil.isNotEmpty(equipmentid)) {
                    ArrayList<AttrBean> attrlist = new ArrayList<>();
                    try {
                        String timestamp = "";
                        Date acquisitiontime = item.getAcquisitiontime();
                        if (acquisitiontime != null) {
                            timestamp = DateUtil.format(acquisitiontime, DatePattern.NORM_DATETIME_PATTERN);
                        }
                        if (phase != null) {
                            AttrBean<String> attr = new AttrBean<>();
                            attr.setKey("Phase");
                            attr.setValue(phase);
                            attrlist.add(attr);
                        }
                        Float h2 = item.getH2();
                        if (h2 != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("H2");
                            attr.setValue(h2);
                            attrlist.add(attr);
                        }
                        Float ch4 = item.getCh4();
                        if (ch4 != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("CH4");
                            attr.setValue(ch4);
                            attrlist.add(attr);
                        }
                        Float c2h6 = item.getC2h6();
                        if (c2h6 != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("C2H6");
                            attr.setValue(c2h6);
                            attrlist.add(attr);
                        }
                        Float c2h4 = item.getC2h4();
                        if (c2h4 != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("C2H4");
                            attr.setValue(c2h4);
                            attrlist.add(attr);
                        }
                        Float c2h2 = item.getC2h2();
                        if (c2h2 != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("C2H2");
                            attr.setValue(c2h2);
                            attrlist.add(attr);
                        }
                        Float co = item.getCo();
                        if (co != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("CO");
                            attr.setValue(co);
                            attrlist.add(attr);
                        }
                        Float co2 = item.getCo2();
                        if (co2 != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("CO2");
                            attr.setValue(co2);
                            attrlist.add(attr);
                        }
                        Float o2 = item.getO2();
                        if (o2 != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("O2");
                            attr.setValue(o2);
                            attrlist.add(attr);
                        }
                        Float n2 = item.getN2();
                        if (n2 != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("N2");
                            attr.setValue(n2);
                            attrlist.add(attr);
                        }
                        Float totalhydrocarbon = item.getTotalhydrocarbon();
                        if (totalhydrocarbon != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("TotalHydrocarbon");
                            attr.setValue(totalhydrocarbon);
                            attrlist.add(attr);
                        }
                        String cacdata = GenerateI2Xml.generateCacXml(Constant.YSP, sensorid, equipmentid, timestamp, attrlist);
                        cacdatalist.add(cacdata);
                        BigInteger id = item.getId();
                        idlist.add(id);

                        SendDataBean sendDataBean = new SendDataBean();
                        sendDataBean.setEqmid(item.getEqmid());
                        sendDataBean.setMaxid(id);
                        list2.add(sendDataBean);
                        eqmidlist.add(item.getEqmid());
                        if (id != null) {
                            int i = id.compareTo(maxid);
                            if (i == 1) {
                                maxid = id;
                            }
                        }
                        if ((index != 0 && index % 79 == 0) || index == (list.size() - 1)) {
                            ArrayList<BigInteger> list1 = new ArrayList<>();
                            String xml = GenerateI2Xml.generateEndCacXml(cacdatalist);
                            list1.addAll(idlist);
//                            asyncMethod.sendJBFDData(client, list2, xml, Constant.YSP);
                            asyncMethod.sendJBFDData2(client,maxid, eqmidlist, xml, Constant.YSP);
                            maxid = BigInteger.valueOf(0);
                            eqmidlist = new ArrayList<>();
                            idlist = new ArrayList<>();
                            cacdatalist = new ArrayList<>();
                        }
                    } catch (Exception e) {
                        log.error("抛出了异常：{}" + e.getMessage());
                    }
                }
            }
        } else {
            log.info("没有查询到ysp的数据");
        }
    }

    @Override
    public void upload_microclimate(Client client, HashMap<Integer, Niec_Sensors> equipMap) {
        List<Data_Microclimate> list = data_microclimateDao.selectUpload(CommonStatus.UNUPLOAD.value());
        if (CollectionUtil.isNotEmpty(list)) {
            log.info("查询microclimate的数据量：" + list.size());
            ArrayList<String> cacdatalist = new ArrayList<>();
            ArrayList<BigInteger> idlist = new ArrayList<>();
            for (int index = 0; index < list.size(); index++) {
                Data_Microclimate item = list.get(index);
                Niec_Sensors sensors = equipMap.get(item.getEqmid());
                String sensorid = sensors.getSensorCode();
                String equipmentid = sensors.getEquipmentId();
                String phase = sensors.getPhase();
                if (StrUtil.isNotEmpty(sensorid) && StrUtil.isNotEmpty(equipmentid)) {
                    ArrayList<AttrBean> attrlist = new ArrayList<>();
                    try {
                        String timestamp = "";
                        Date acquisitiontime = item.getAcquisitiontime();
                        if (acquisitiontime != null) {
                            timestamp = DateUtil.format(acquisitiontime, DatePattern.NORM_DATETIME_PATTERN);
                        }
                        if (phase != null) {
                            AttrBean<String> attr = new AttrBean<>();
                            attr.setKey("Phase");
                            attr.setValue(phase);
                            attrlist.add(attr);
                        }
                        Float airtemperature = item.getAirtemperature();
                        if (airtemperature != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("AirTemperature");
                            attr.setValue(airtemperature);
                            attrlist.add(attr);
                        }
                        Float airpressure = item.getAirpressure();
                        if (airpressure != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("AirPressure");
                            attr.setValue(airpressure);
                            attrlist.add(attr);
                        }
                        Float humidity = item.getHumidity();
                        if (humidity != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("Humidity");
                            attr.setValue(humidity);
                            attrlist.add(attr);
                        }
                        Float precipitation = item.getPrecipitation();
                        if (precipitation != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("Precipitation");
                            attr.setValue(precipitation);
                            attrlist.add(attr);
                        }
                        Float precipitationintensity = item.getPrecipitationintensity();
                        if (precipitationintensity != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("PrecipitationIntensity");
                            attr.setValue(precipitationintensity);
                            attrlist.add(attr);
                        }
                        Float radiationintensity = item.getRadiationintensity();
                        if (radiationintensity != null) {
                            AttrBean<Float> attr = new AttrBean<>();
                            attr.setKey("RadiationIntensity");
                            attr.setValue(radiationintensity);
                            attrlist.add(attr);
                        }
                        String cacdata = GenerateI2Xml.generateCacXml(Constant.WQX, sensorid, equipmentid, timestamp, attrlist);
                        cacdatalist.add(cacdata);
                        idlist.add(item.getId());
                        if ((index != 0 && index % 79 == 0) || index == (list.size() - 1)) {
                            ArrayList<BigInteger> list1 = new ArrayList<>();
                            String xml = GenerateI2Xml.generateEndCacXml(cacdatalist);
                            list1.addAll(idlist);
                            asyncMethod.sendData(client, list1, xml, Constant.WQX);
                            idlist = new ArrayList<>();
                            cacdatalist = new ArrayList<>();
                        }
                    } catch (Exception e) {
                        log.error("抛出了异常：{}" + e.getMessage());
                    }
                }
            }
        } else {
            log.info("没有查询到microcimate的数据");
        }
    }
}
